@@ -1,6 +1,6 @@
 from django import forms
 from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tastypie.models import ApiKey
 from tendenci.apps.perms.models import TendenciBaseModel
