@@ -82,35 +82,43 @@ def search(request, template_name="articles/search.html"):
     cat = None
     category = None
     sub_category = None
+    query = None
 
     if not request.user.is_anonymous:
         articles = articles.select_related()
 
-    query = request.GET.get('q', None)
-    if query:
-        # Handle legacy tag links
-        if "tag:" in query:
-            return HttpResponseRedirect("%s?q=%s&search_category=tags__icontains" %(reverse('articles'), query.replace('tag:', '')))
-
-        # Handle legacy category links
-        if "category:" in query or "sub_category:" in query:
-            key, name = query.split(':', 1)
-            category = Category.objects.filter(name__iexact=name)
-            if category.exists():
-                return HttpResponseRedirect("%s?%s=%s" %(reverse('articles'), key, name))
-            else:
-                return HttpResponseRedirect(reverse('articles'))
-
     tag = request.GET.get('tag', None)
-    form = ArticleSearchForm(request.GET, is_superuser=request.user.is_superuser)
 
     if tag:
         articles = articles.filter(tags__icontains=tag)
 
+    form = ArticleSearchForm(request.GET, is_superuser=request.user.is_superuser)
     if form.is_valid():
+        query = form.cleaned_data.get('q', None)
+        if query:
+            # Handle legacy tag links
+            if "tag:" in query:
+                return HttpResponseRedirect("%s?q=%s&search_category=tags__icontains" %(reverse('articles'), query.replace('tag:', '')))
+    
+            # Handle legacy category links
+            if "category:" in query or "sub_category:" in query:
+                key, name = query.split(':', 1)
+                categories = Category.objects.filter(name__iexact=name)
+                if categories.exists():
+                    category = categories[0]
+                    return HttpResponseRedirect("%s?%s=%s" %(reverse('articles'), key, category.id))
+                else:
+                    return HttpResponseRedirect(reverse('articles'))
+
         cat = form.cleaned_data['search_category']
-        category = form.cleaned_data['category']
-        sub_category = form.cleaned_data['sub_category']
+        try:
+            category = int(form.cleaned_data['category'])
+        except ValueError:
+            category = None
+        try:
+            sub_category = int(form.cleaned_data['sub_category'])
+        except ValueError:
+            sub_category = None
         filter_date = form.cleaned_data['filter_date']
         date = form.cleaned_data['date']
         try:
@@ -137,9 +145,9 @@ def search(request, template_name="articles/search.html"):
 
     # Query list of category and subcategory for dropdown filters
     if category:
-        articles = articles.filter(categories__category__name=category)
+        articles = articles.filter(categories__category__id=category)
     if sub_category:
-        articles = articles.filter(categories__parent__name=sub_category)
+        articles = articles.filter(categories__parent__id=sub_category)
 
     # don't use order_by with "whoosh"
     default_engine = settings.HAYSTACK_CONNECTIONS.get('default', {}).get('ENGINE', '')
@@ -157,11 +165,18 @@ def search(request, template_name="articles/search.html"):
         base_template = 'articles/base.html'
         num_per_page = 10
 
+    file_id = get_setting('module', 'articles', 'headerimage')
+    if file_id:
+        header_image_url = reverse('file', args=(file_id, ))
+    else:
+        header_image_url = ''
+
     return render_to_resp(request=request, template_name=template_name,
         context={'articles': articles,
                  'form' : form,
                  'base_template': base_template,
-                 'num_per_page': num_per_page})
+                 'num_per_page': num_per_page,
+                 'header_image_url': header_image_url})
 
 
 def search_redirect(request):
@@ -408,7 +423,7 @@ def export(request, template_name="articles/export.html"):
     if request.method == "POST" and "download" in request.POST:
         identifier = int(time.time())
         temp_file_path = 'export/articles/%s_temp.csv' % identifier
-        default_storage.save(temp_file_path, ContentFile(''))
+        default_storage.save(temp_file_path, ContentFile(b''))
 
         # start the process
         subprocess.Popen([python_executable(), "manage.py",
