@@ -1,6 +1,6 @@
 from django.contrib import admin
 from django.template.defaultfilters import truncatewords_html
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.safestring import mark_safe
 
 from tendenci.apps.perms.admin import TendenciBaseModelAdmin
