@@ -452,20 +452,22 @@ class DirectoryForm(TendenciBaseForm):
             directory.requested_duration = self.cleaned_data['pricing'].duration
 
         if self.cleaned_data['logo']:
-            file_object, created = File.objects.get_or_create(
-                file=self.cleaned_data['logo'],
-                defaults={
-                    'name': self.cleaned_data['logo'].name,
-                    'content_type': content_type,
-                    'object_id': directory.pk,
-                    'is_public': directory.allow_anonymous_view,
-                    'tags': directory.tags,
-                    'creator': self.user,
-                    'owner': self.user,
-                })
+            [file_object] = File.objects.filter(file=self.cleaned_data['logo'],
+                                              content_type=content_type,
+                                              object_id=directory.pk)[:1] or [None]
+            if not file_object:
+                file_object = File.objects.create(
+                                file=self.cleaned_data['logo'],
+                                name=self.cleaned_data['logo'].name,
+                                content_type=content_type,
+                                object_id=directory.pk,
+                                is_public=directory.allow_anonymous_view,
+                                tags=directory.tags,
+                                creator=self.user,
+                                owner=self.user)
 
-            directory.logo_file = file_object
-            directory.save(log=False)
+                directory.logo_file = file_object
+                directory.save(log=False)
 
         # clear logo; if box checked
         if self.cleaned_data['logo'] is False:
