@@ -1,6 +1,6 @@
 from django.db import models
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from picklefield.fields import PickledObjectField
 #from tendenci.apps.memberships.models import App
 
