@@ -401,9 +401,9 @@ def auto_delete_file_on_change(sender, instance, **kwargs):
         return False
 
     new_file = instance.file
-    if not old_file == new_file:
-        if os.path.isfile(old_file.path):
-            os.remove(old_file.path)
+    if old_file != new_file:
+        if default_storage.exists(old_file.name):
+            default_storage.delete(old_file.name)
 
 
 @receiver(models.signals.post_delete, sender=File)
@@ -412,8 +412,8 @@ def auto_delete_file_on_delete(sender, instance, **kwargs):
     when corresponding `File` object is deleted.
     """
     if instance.file:
-        if os.path.isfile(instance.file.path):
-            os.remove(instance.file.path)
+        if default_storage.exists(instance.file.name):
+            default_storage.delete(instance.file.name)
 
 
 class FilesCategory(models.Model):
