@@ -16,7 +16,7 @@ from django.conf import settings
 from haystack.query import SearchQuerySet
 from tendenci.libs.tinymce.widgets import TinyMCE
 
-from tendenci.apps.base.fields import EmailVerificationField, PriceField, CountrySelectField
+from tendenci.apps.base.fields import EmailVerificationField, PriceField, CountrySelectField, StateSelectField
 from tendenci.apps.base.forms import FormControlWidgetMixin
 from tendenci.apps.careers.models import Career
 from tendenci.apps.corporate_memberships.models import (CorpMembership, CorpMembershipAuthDomain, CorporateMembershipType)
@@ -115,6 +115,9 @@ def assign_search_fields(form, app_field_objs):
             elif obj.field_name == 'country':
                 form.fields[obj.field_name] = CountrySelectField(label=obj.label,
                                                     required=False)
+            elif obj.field_name == 'state' and get_setting('site', 'global', 'stateusesdropdown'):
+                form.fields[obj.field_name] = StateSelectField(label=obj.label,
+                                                    required=False)
             elif obj.field_name == 'language':
                 form.fields[obj.field_name] = forms.ChoiceField(label=obj.label,
                                                     required=False,
@@ -586,6 +589,10 @@ class MembershipAppFieldAdminForm(forms.ModelForm):
                 self.fields['field_type'].choices = MembershipAppField.FIELD_TYPE_CHOICES2
             else:
                 self.fields['field_type'].choices = MembershipAppField.FIELD_TYPE_CHOICES1
+            if self.instance.field_name == 'state':
+                self.fields['field_type'].choices = (("", _("Set to Default")),
+                                                ("CharField", _("Text")),
+                                                ("StateProvinceField", _("States/Provinces")),)
 
     def save(self, *args, **kwargs):
         self.instance = super(MembershipAppFieldAdminForm, self).save(*args, **kwargs)
@@ -672,6 +679,9 @@ def assign_fields(form, app_field_objs):
                     field.initial = obj.default_value
                 form.fields[obj.field_name] = field
             else:
+                if obj.field_name in ['state', 'state_2']:
+                    if get_setting('site', 'global', 'stateusesdropdown'):
+                        form.fields[obj.field_name] = StateSelectField()
                 field = form.fields[obj.field_name]
                 field.label = obj.label
                 field.required = obj.required
@@ -777,6 +787,14 @@ class UserForm(FormControlWidgetMixin, forms.ModelForm):
             Username and password did not match
             This username exists. If it's yours,
                 please provide a password.
+            If username field is blank or not presented:
+                 if email address is in the system
+                     if user is not logged in
+                        if the user record with this email address is active
+                            prompts them to log in
+                        else
+                            let them activate the account before applying for membership
+
         """
         # super(UserForm, self).clean()
 
@@ -794,16 +812,16 @@ class UserForm(FormControlWidgetMixin, forms.ModelForm):
                                                     activate_link=reverse('profile.activate_email'),
                                                     username=requests.utils.quote(un), email=requests.utils.quote(email),
                                                     next_path=self.request.get_full_path())
-        inactive_user_err_msg =  mark_safe(_('''This email "{email}" is associated with previous site activity.
+        inactive_user_err_msg =  mark_safe(_('''The email you entered is associated with previous site activity.
                     Please click {activation_link} and we'll send you an email to activate your account and then you
-                    will be returned to this application.''').format(email=email, activation_link=activation_link))
+                    will be returned to this application.''').format(activation_link=activation_link))
 
         if self.request.user.is_authenticated and self.request.user.username == un:
             # they are logged in and join or renewal for themselves
             if email and email !=  self.request.user.email:
                 # email is changed
                 if User.objects.filter(email=email).exists():
-                    raise forms.ValidationError(_('''This Email address "%s" already exists in the system.
+                    raise forms.ValidationError(_('''This Email address you entered "%s" already exists in the system.
                                     Please select a different one to continue.''') % email)
 
         else:
@@ -841,17 +859,19 @@ class UserForm(FormControlWidgetMixin, forms.ModelForm):
                     if User.objects.filter(email=email).exists():
                         if self.request.user.is_authenticated:
                             # user is logged in
-                            raise forms.ValidationError(_('This email "%s" is taken. Please check username or enter a different email address.') % email)
+                            if 'username' in data:
+                                # username is presented on form
+                                raise forms.ValidationError(_('This email "%s" is taken. Please check username or enter a different email address.') % email)
+                        else:
+                            # user is not logged in. prompt them to log in if the user record with this email address is active
+                            u = User.objects.filter(email=email).order_by('-is_active')[0]
+                            [profile] = Profile.objects.filter(user=u)[:1] or [None]
+                            if (profile and profile.is_active) and u.is_active:
+                                raise forms.ValidationError(email_validate_err_msg)
 
-                        # user is not logged in. prompt them to log in if the user record with this email address is active
-                        u = User.objects.filter(email=email).order_by('-is_active')[0]
-                        [profile] = Profile.objects.filter(user=u)[:1] or [None]
-                        if (profile and profile.is_active) or u.is_active:
-                            raise forms.ValidationError(email_validate_err_msg)
-
-                        # at this point, user is not logged in and user record with this email is inactive
-                        # let them activate the account before applying for membership
-                        raise forms.ValidationError(inactive_user_err_msg)
+                            # at this point, user is not logged in and user record with this email is inactive
+                            # let them activate the account before applying for membership
+                            raise forms.ValidationError(inactive_user_err_msg)
 
         return data
 
@@ -1077,7 +1097,7 @@ class DemographicsForm(FormControlWidgetMixin, forms.ModelForm):
         self.request = kwargs.pop('request', None)
         self.membership = kwargs.pop('membership', None)
         super(DemographicsForm, self).__init__(*args, **kwargs)
-        assign_fields(self, app_field_objs)
+        
         self.field_names = [name for name in self.fields]
         self.file_upload_fields = {}
         # change the default widget to TextInput instead of TextArea
@@ -1089,6 +1109,11 @@ class DemographicsForm(FormControlWidgetMixin, forms.ModelForm):
             if field.widget.__class__.__name__.lower() == 'selectdatewidget':
                 field.widget.years = list(range(1920, THIS_YEAR + 10))
 
+        # Assign fields (including widget) based on how user specified.
+        # Moved down here otherwise the widget would be overridden by
+        # the above code which sets the default widget to TextInput
+        assign_fields(self, app_field_objs)
+
         self.app = None
         self.demographics = None
         if self.membership:
@@ -1850,6 +1875,13 @@ class MembershipDefaultForm(TendenciBaseForm):
                     mt_choices.append((pk, '%s $%s' % (name, price)))
 
         self.fields['membership_type'].choices = mt_choices
+
+        # state
+        if get_setting('site', 'global', 'stateusesdropdown'):
+            self.fields['state'] = StateSelectField(label=self.fields['state'].label,
+                                                    required=self.fields['state'].required)
+            self.fields['state_2'] = StateSelectField(label=self.fields['state_2'].label,
+                                                    required=self.fields['state_2'].required)
         # -----------------------------------------------------
 
         # change form -----------------------------------------
