@@ -1,7 +1,7 @@
 from datetime import datetime, timedelta
 
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.memberships.notices.utils import get_membership_notice_choices
 
