@@ -88,4 +88,7 @@ urlpatterns = [
     re_path(r'^%s/(?P<id>\d+)/(?P<size>\d+x\d+)/(?P<constrain>[constrain]*)/$' % urlpath, views.photo_size, name="photo.size"),
     re_path(r'^%s/(?P<id>\d+)/(?P<size>\d+x\d+)/(?P<crop>[crop]*)/(?P<quality>\d+)/$' % urlpath, views.photo_size, name="photo.size"),
     re_path(r'^%s/(?P<id>\d+)/(?P<size>\d+x\d+)/(?P<constrain>[constrain]*)/(?P<quality>\d+)/$' % urlpath, views.photo_size, name="photo.size"),
+
+    ## Photos in category ##
+    re_path(r'^%s/(?P<slug>[\w\-\/]+)/$' % urlpath, views.category_photos, name='photos_in_category'),
 ]
