@@ -194,7 +194,7 @@ def index(request, username='', template_name="profiles/index.html"):
     city_state = ', '.join([s for s in (profile.city, profile.state) if s])
     city_state_zip = ', '.join([s for s in (profile.city, state_zip, profile.country) if s])
 
-    can_edit = has_perm(request.user, 'profiles.change_profile', user_this)
+    can_edit = profile.allow_edit_by(request.user)
 
     if not can_edit:
         can_edit = request.user == user_this
@@ -1038,14 +1038,13 @@ def user_role_edit(request, username, membership_id, form_class=GroupMembershipE
 
 @login_required
 def user_membership_add(request, username, form_class=UserMembershipForm, template_name="profiles/add_membership.html"):
+    user = get_object_or_404(User, username=username)
     redirect_url = reverse('membership_default.add')
-    redirect_url = '%s?username=%s' % (redirect_url, username)
+    redirect_url = '%s?username=%s' % (redirect_url, user.username)
     # this view is redundant and not handling membership add well.
     # redirect to membership add
     return redirect(redirect_url)
 
-    user = get_object_or_404(User, username=username)
-
     try:
         Profile.objects.get(user=user)
     except Profile.DoesNotExist:
@@ -1366,7 +1365,7 @@ def profile_export(request, template_name="profiles/export.html"):
         export_fields = form.cleaned_data['export_fields']
         identifier = int(time.time())
         temp_file_path = 'export/profiles/%s_temp.csv' % identifier
-        default_storage.save(temp_file_path, ContentFile(''))
+        default_storage.save(temp_file_path, ContentFile(b''))
 
         # start the process
         subprocess.Popen([python_executable(), "manage.py",
