@@ -7,7 +7,7 @@ from django.template import TemplateDoesNotExist
 from django.conf import settings
 from django.contrib.auth.models import User
 from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from dateutil.relativedelta import relativedelta
 from tendenci.apps.emails.models import Email
 from tendenci.apps.site_settings.utils import get_setting
