@@ -2,6 +2,7 @@ from django.template import Library
 
 register = Library()
 
+
 @register.inclusion_tag("user_groups/options.html", takes_context=True)
 def user_group_options(context, user, group):
     context.update({
@@ -10,6 +11,7 @@ def user_group_options(context, user, group):
     })
     return context
 
+
 @register.inclusion_tag("user_groups/nav.html", takes_context=True)
 def user_group_nav(context, user, group=None):
     context.update({
@@ -18,6 +20,16 @@ def user_group_nav(context, user, group=None):
     })
     return context
 
+
+@register.inclusion_tag("user_groups/top_nav_items.html", takes_context=True)
+def user_group_current_app(context, user, group=None):
+    context.update({
+        "app_object": group,
+        "user": user
+    })
+    return context
+
+
 @register.inclusion_tag("user_groups/search-form.html", takes_context=True)
 def group_search(context):
     return context
